@@ -1,7 +1,7 @@
 /*
  * guile-server.c - guile server modules
  *
- * Copyright (C) 2001, 2002, 2003 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2001, 2002, 2003, 2004 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: guile-server.c,v 1.54 2003/04/06 20:01:25 ela Exp $
+ * $Id: guile-server.c,v 1.58 2008/04/25 19:11:46 ela Exp $
  *
  */
 
@@ -33,6 +33,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
+#if HAVE_FLOSS_H
+# include <floss.h>
+#endif
 #if GUILE_SOURCE
 # include <libguile/gh.h>
 #else
@@ -1231,7 +1234,7 @@ guile_servertype_config_free (svz_servertype_t *server)
   svz_free (prototype->items);
 }
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
 /*
  * Debug helper: Display a text representation of the configuration items
  * of a guile servertype.
@@ -1298,7 +1301,7 @@ guile_servertype_config_print (svz_servertype_t *server)
 	}
     }
 }
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
 /*
  * Obtain a default value from the scheme cell @var{value}. The configuration
@@ -1420,15 +1423,14 @@ static int
 guile_servertype_config (svz_servertype_t *server, SCM cfg)
 {
   int def, n, err = 0;
-  char *txt, **key;
+  char *txt = NULL, **key;
   svz_hash_t *options = NULL;
   svz_key_value_pair_t item;
   svz_key_value_pair_t *items = NULL;
   char *prototype = NULL;
   int size = 0, len;
 
-  txt = svz_malloc (256);
-  svz_snprintf (txt, 256, "parsing configuration of `%s'", server->prefix);
+  svz_asprintf (&txt, "parsing configuration of `%s'", server->prefix);
 
   /* Check if the configuration alist is given or not. */
   if (SCM_EQ_P (cfg, SCM_UNSPECIFIED))
@@ -1558,15 +1560,14 @@ SCM
 guile_define_servertype (SCM args)
 {
   int n, err = 0;
-  char *txt;
+  char *txt = NULL;
   svz_hash_t *options;
   SCM proc;
   svz_servertype_t *server;
   svz_hash_t *functions;
 
   server = svz_calloc (sizeof (svz_servertype_t));
-  txt = svz_malloc (256);
-  svz_snprintf (txt, 256, "defining servertype");
+  svz_asprintf (&txt, "defining servertype");
 
   if (NULL == (options = guile_to_optionhash (args, txt, 0)))
     FAIL (); /* Message already emitted. */
@@ -1575,7 +1576,7 @@ guile_define_servertype (SCM args)
   if (optionhash_extract_string (options, "prefix", 0, NULL, 
 				 &server->prefix, txt) != 0)
     FAIL ();
-  svz_snprintf (txt, 256, "defining servertype `%s'", server->prefix);
+  svz_asprintf (&txt, "defining servertype `%s'", server->prefix);
   
   /* Check the servertype definition once. */
   err |= optionhash_validate (options, 1, "servertype", server->prefix);
@@ -1588,6 +1589,7 @@ guile_define_servertype (SCM args)
   functions = svz_hash_create (4, (svz_free_func_t) guile_unprotect);
   for (n = 0; guile_functions[n] != NULL; n++)
     {
+      proc = SCM_UNDEFINED;
       err |= optionhash_extract_proc (options, guile_functions[n],
 				      1, SCM_UNDEFINED, &proc, txt);
       svz_hash_put (functions, guile_functions[n], SVZ_NUM2PTR (proc));
