@@ -1,7 +1,7 @@
 /*
  * guile.h - interface to guile core library declarations
  *
- * Copyright (C) 2001 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2001, 2003 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: guile.h,v 1.13 2002/07/29 18:32:09 ela Exp $
+ * $Id: guile.h,v 1.14 2003/04/06 20:01:25 ela Exp $
  *
  */
 
@@ -30,10 +30,10 @@
  * symbol. Returns @code{NULL} if it was neither. The new string must be 
  * explicitly @code{free()}d.
  */
-#define guile_to_string(cell)                                   \
-  (SCM_NULLP (cell) ? NULL :                                    \
-  (SCM_STRINGP (cell) ? gh_scm2newstr (cell, NULL) :            \
-  (SCM_SYMBOLP (cell) ? gh_symbol2newstr (cell, NULL) : NULL)))
+#define guile_to_string(cell)					      \
+  (SCM_NULLP (cell) ? NULL :					      \
+  (SCM_STRINGP (cell) ? scm_c_string2str (cell, NULL, NULL) :	      \
+  (SCM_SYMBOLP (cell) ? scm_c_symbol2str (cell, NULL, NULL) : NULL)))
 
 /* FAIL breaks to the label `out' and sets an error condition. */
 #define FAIL() do { err = -1; goto out; } while(0)
