@@ -1,7 +1,7 @@
 /*
  * http-core.c - http core functionality
  *
- * Copyright (C) 2000, 2001 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2000, 2001, 2003 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.  
  *
- * $Id: http-core.c,v 1.44 2002/01/20 17:12:29 ela Exp $
+ * $Id: http-core.c,v 1.45 2003/06/14 14:57:59 ela Exp $
  *
  */
 
@@ -209,13 +209,13 @@ http_userdir (svz_socket_t *sock, char *uri)
 	  svz_free (user);
 	  return file;
 	}
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       else if (entry)
 	{
 	  svz_log (LOG_DEBUG, "http: home directory for %s not set\n",
 		   svz_windoze_uni2asc (entry->usri1_name));
 	}
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 #endif /* not HAVE_GETPWNAM and not __MINGW32__ */
 
       svz_free (user);
@@ -459,7 +459,7 @@ http_check_range (http_range_t *range, off_t filesize)
       (range->last != 0 && range->last <= range->first) ||
       (range->last >= filesize || range->length > filesize))
     {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG,
 	       "http: invalid content range (%ld-%ld/%ld not in %ld) \n",
 	       range->first, range->last, range->length, filesize);
@@ -490,7 +490,7 @@ http_get_range (char *line, http_range_t *range)
   if (strlen (p) >= HTTP_BYTES_LENGTH && 
       memcmp (p, HTTP_BYTES, HTTP_BYTES_LENGTH))
     {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "http: invalid byte-range specifier (%s)\n", p);
 #endif
       return -1;
@@ -664,7 +664,7 @@ http_keep_alive (svz_socket_t *sock)
       sock->write_socket = http_default_write;
       sock->send_buffer_fill = 0;
       sock->idle_func = http_idle;
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "http: keeping connection alive\n");
 #endif
       return 0;
@@ -1071,7 +1071,7 @@ http_absolute_file (char *file)
     {
       *p = '/';
       svz_log (LOG_ERROR, "chdir: %s\n", SYS_ERROR);
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "cannot change dir: %s\n", file);
 #endif
       svz_free (savefile);
