@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: interface.c,v 1.12 2002/01/06 13:18:52 ela Exp $
+ * $Id: interface.c,v 1.14 2002/10/13 08:11:59 ela Exp $
  *
  */
 
@@ -37,12 +37,15 @@
 #ifndef __MINGW32__
 # include <sys/types.h>
 # include <sys/socket.h>
-# include <sys/ioctl.h>
 # include <net/if.h>
 # include <netinet/in.h>
 # include <arpa/inet.h>
 #endif
 
+#if HAVE_SYS_IOCTL_H
+# include <sys/ioctl.h>
+#endif
+
 #if HAVE_UNISTD_H
 # include <unistd.h>
 #endif
@@ -739,7 +742,7 @@ svz_interface_check (void)
       svz_vector_destroy (interfaces);
     }
 
-  /* Print a notification message if no changes occured. */
+  /* Print a notification message if no changes occurred. */
   if (!changes)
     {
       svz_log (LOG_NOTICE, "no network interface changes detected\n");
