@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.  
  *
- * $Id: raw-socket.h,v 1.5 2001/08/01 10:16:22 ela Exp $
+ * $Id: raw-socket.h,v 1.6 2001/12/13 18:00:00 ela Exp $
  *
  */
 
@@ -68,10 +68,10 @@ svz_ip_header_t;
 __BEGIN_DECLS
 
 /* Exported RAW IP socket functions. */
-SERVEEZ_API svz_ip_header_t * svz_raw_get_ip_header __P ((svz_uint8_t *));
-SERVEEZ_API svz_uint8_t * svz_raw_put_ip_header __P ((svz_ip_header_t *));
-SERVEEZ_API unsigned short svz_raw_ip_checksum __P ((svz_uint8_t *, int));
-SERVEEZ_API int svz_raw_check_ip_header __P ((svz_uint8_t *, int));
+SERVEEZ_API svz_ip_header_t * svz_raw_get_ip_header __PARAMS ((svz_uint8_t *));
+SERVEEZ_API svz_uint8_t * svz_raw_put_ip_header __PARAMS ((svz_ip_header_t *));
+SERVEEZ_API unsigned short svz_raw_ip_checksum __PARAMS ((svz_uint8_t *, int));
+SERVEEZ_API int svz_raw_check_ip_header __PARAMS ((svz_uint8_t *, int));
 
 __END_DECLS
 
