@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.  
  *
- * $Id: server-core.c,v 1.41 2003/01/05 15:28:08 ela Exp $
+ * $Id: server-core.c,v 1.43 2003/08/26 04:59:33 ela Exp $
  *
  */
 
@@ -117,7 +117,7 @@ static int svz_pipe_broke;
  * @var{svz_child_died} is set to a non-zero value whenever the server
  * receives a SIGCHLD signal.
  */
-HANDLE svz_child_died;
+svz_t_handle svz_child_died;
 
 /*
  * The @var{svz_uncaught_signal} variable is set to a value greater or
@@ -187,7 +187,7 @@ svz_executable (char *file)
 /*
  * Segmentation fault exception handler.
  */
-RETSIGTYPE
+svz_t_retsig
 svz_segfault_exception (int sig)
 {
 #if HAVE_GETRLIMIT
@@ -210,7 +210,7 @@ svz_segfault_exception (int sig)
  * broken pipes (SIGPIPE) and to exit gracefully if requested by the
  * user (SIGINT, SIGTERM).
  */
-RETSIGTYPE 
+svz_t_retsig 
 svz_signal_handler (int sig)
 {
   switch (sig)
@@ -307,7 +307,7 @@ svz_strsignal_init (void)
 {
   int i;
   char *str;
-  const char *format = "Signal %d";
+  svz_c_const char *format = "Signal %d";
 
   if (svz_signal_strings != NULL)
     return;
@@ -380,7 +380,7 @@ svz_abort (char *msg)
   return 0;
 }
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
 /*
  * This function is for debugging purposes only. It shows a text 
  * representation of the current socket list.
@@ -454,7 +454,7 @@ svz_sock_validate_list (void)
     }
   return 0;
 }
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
 /*
  * Rechain the socket list to prevent sockets from starving at the end
@@ -710,7 +710,7 @@ svz_sock_check_access (svz_socket_t *parent, svz_socket_t *child)
 	}
     }
 
-  /* Check allow IP addresses. */
+  /* Check allowed IP addresses. */
   if (port->allow)
     {
       ret = -1;
@@ -914,7 +914,7 @@ svz_reset (void)
 int
 svz_sock_shutdown (svz_socket_t *sock)
 {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
   svz_log (LOG_DEBUG, "shutting down socket id %d\n", sock->id);
 #endif
 
@@ -961,9 +961,9 @@ svz_sock_schedule_for_shutdown (svz_socket_t *sock)
 {
   if (!(sock->flags & SOCK_FLAG_KILLED))
     {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "scheduling socket id %d for shutdown\n", sock->id);
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
       sock->flags |= SOCK_FLAG_KILLED;
 
@@ -994,12 +994,12 @@ svz_periodic_tasks (void)
   sock = svz_sock_root; 
   while (sock)
     {
-#if ENABLE_FLOOD_PROTECTION
+#if SVZ_ENABLE_FLOOD_PROTECTION
       if (sock->flood_points > 0)
 	{
 	  sock->flood_points--;
 	}
-#endif /* ENABLE_FLOOD_PROTECTION */
+#endif /* SVZ_ENABLE_FLOOD_PROTECTION */
 
       if (sock->idle_func && sock->idle_counter > 0)
 	{
@@ -1038,9 +1038,9 @@ svz_sock_check_bogus (void)
 #endif
   svz_socket_t *sock;
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
   svz_log (LOG_DEBUG, "checking for bogus sockets\n");
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
   svz_sock_foreach (sock)
     {
@@ -1207,9 +1207,9 @@ svz_sock_check_children (void)
     if (sock->pid != INVALID_HANDLE && svz_sock_child_died (sock))
       {
 	sock->pid = INVALID_HANDLE;
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
 	svz_log (LOG_DEBUG, "child of socket id %d died\n", sock->id);
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 	if (sock->child_died)
 	  if (sock->child_died (sock))
 	    svz_sock_schedule_for_shutdown (sock);
@@ -1229,9 +1229,9 @@ svz_loop_one (void)
   /*
    * FIXME: Remove this once the server is stable.
    */
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
   svz_sock_validate_list ();
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
   if (svz_reset_happened)
     {
