@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.  
  *
- * $Id: gnutella.c,v 1.45 2002/05/31 14:34:21 ela Exp $
+ * $Id: gnutella.c,v 1.46 2002/12/05 16:57:56 ela Exp $
  *
  */
 
@@ -173,9 +173,7 @@ svz_servertype_t nut_server_definition =
   nut_server_notify,                      /* server timer routine */
   NULL,                                   /* no reset callback */
   NULL,                                   /* no handle request callback */
-  &nut_config,                            /* default configuration */
-  sizeof (nut_config),                    /* size of this configuration */
-  nut_config_prototype                    /* configuration items */
+  SVZ_CONFIG_DEFINE ("nut", nut_config, nut_config_prototype)
 };
 
 /*
