@@ -1,7 +1,7 @@
 /*
  * nut-transfer.c - gnutella file transfer implementation
  *
- * Copyright (C) 2000, 2001 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2000, 2001, 2003, 2004 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.  
  *
- * $Id: nut-transfer.c,v 1.40 2001/12/22 10:32:52 ela Exp $
+ * $Id: nut-transfer.c,v 1.42 2004/03/20 10:43:32 ela Exp $
  *
  */
 
@@ -35,6 +35,9 @@
 #include <ctype.h>
 #include <time.h>
 #include <sys/stat.h>
+#if HAVE_FLOSS_H
+# include <floss.h>
+#endif
 #if HAVE_UNISTD_H
 # include <unistd.h>
 #endif
@@ -197,7 +200,7 @@ nut_save_transfer (svz_socket_t *sock)
       /* did we get all data */
       if ((transfer->size -= num_written) <= 0)
 	{
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
 	  svz_log (LOG_DEBUG, "nut: file successfully received\n");
 #endif
 	  /* yes, shutdown the connection */
@@ -230,7 +233,7 @@ nut_check_transfer (svz_socket_t *sock)
       /* did we get all the header information ? */
       if (p < sock->recv_buffer + (fill - 3) && !memcmp (p, NUT_SEPERATOR, 4))
 	{
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
 	  svz_log (LOG_DEBUG, "nut: download header received\n");
 #endif
 
@@ -238,7 +241,7 @@ nut_check_transfer (svz_socket_t *sock)
 	  length = nut_parse_property (sock->recv_buffer, len, NUT_LENGTH);
 	  if (length == NULL)
 	    {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
 	      svz_log (LOG_DEBUG, "nut: no content length given\n");
 #endif
 	      return -1;
@@ -305,7 +308,7 @@ nut_disconnect_transfer (svz_socket_t *sock)
       /* if the transfer was really aborted we remove the downloaded file */
       if (transfer->size > 0 || !(sock->userflags & NUT_FLAG_HDR))
 	{
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
 	  svz_log (LOG_DEBUG, "nut: downloading `%s' aborted\n",
 		   transfer->file);
 #endif
@@ -576,7 +579,7 @@ nut_send_push (nut_config_t *cfg, nut_transfer_t *transfer)
       sprintf (pushkey, "%d:%s", push.index, nut_text_guid (push.id));
       if ((trans = svz_hash_get (cfg->push, pushkey)) != NULL)
 	{
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
 	  svz_log (LOG_DEBUG, "nut: push request already sent\n");
 #endif
 	  svz_free (pushkey);
@@ -601,7 +604,7 @@ nut_send_push (nut_config_t *cfg, nut_transfer_t *transfer)
       svz_hash_put (cfg->push, pushkey, trans);
       svz_free (pushkey);
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "nut: sent push request to %s:%u\n",
 		  svz_inet_ntoa (sock->remote_addr), 
 		  ntohs (sock->remote_port));
@@ -729,7 +732,7 @@ nut_read_database_r (nut_config_t *cfg, char *dirname, int depth)
       if (svz_snprintf (filename, NUT_PATH_SIZE - 1, "%s/*", dirname) == -1)
 	return;
       
-      if ((dir = FindFirstFile (filename, &de)) != INVALID_HANDLE_VALUE)
+      if ((dir = FindFirstFile (filename, &de)) != INVALID_HANDLE)
 #else
       if ((dir = opendir (dirname)) != NULL)
 #endif
@@ -798,7 +801,7 @@ nut_check_upload (svz_socket_t *sock)
 
   if (p < sock->recv_buffer + (fill - 3) && !memcmp (p, NUT_SEPERATOR, 4))
     {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "nut: upload header received\n");
 #endif
       /* parse first (GET) line */
@@ -837,7 +840,7 @@ nut_check_upload (svz_socket_t *sock)
       /* find file in database */
       if ((entry = nut_get_database (sock->cfg, file, index)) == NULL)
 	{
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
 	  svz_log (LOG_DEBUG, "nut: no such file: %s, %u\n", file, index);
 #endif
 	  svz_free (file);
@@ -989,7 +992,7 @@ nut_file_read (svz_socket_t *sock)
   /* Read all file data ? */
   if (transfer->size <= 0)
     {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "nut: file successfully read\n");
 #endif
       /* 
@@ -1059,7 +1062,7 @@ nut_file_write (svz_socket_t *sock)
 
   if (sock->send_buffer_fill == 0 && transfer->size <= 0)
     {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "nut: file successfully sent\n");
 #endif
       return -1;
