@@ -1,7 +1,7 @@
 /*
  * sntp-proto.c - simple network time protocol implementation
  *
- * Copyright (C) 2000, 2001 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2000, 2001, 2002 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.  
  *
- * $Id: sntp-proto.c,v 1.11 2002/05/31 14:34:22 ela Exp $
+ * $Id: sntp-proto.c,v 1.12 2002/12/05 16:57:56 ela Exp $
  *
  */
 
@@ -86,9 +86,7 @@ svz_servertype_t sntp_server_definition =
   NULL,
   NULL,
   sntp_handle_request,
-  &sntp_config,
-  sizeof (sntp_config),
-  sntp_config_prototype
+  SVZ_CONFIG_DEFINE ("sntp", sntp_config, sntp_config_prototype)
 };
 
 /*
