@@ -1,7 +1,7 @@
 /*
  * tunnel.c - port forward implementations
  *
- * Copyright (C) 2000, 2001, 2002 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2000, 2001, 2002, 2003 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.  
  *
- * $Id: tunnel.c,v 1.31 2002/12/05 16:57:56 ela Exp $
+ * $Id: tunnel.c,v 1.32 2003/06/14 14:58:00 ela Exp $
  *
  */
 
@@ -263,10 +263,10 @@ tnl_create_socket (svz_socket_t *sock, int source)
 	  return NULL;
 	}
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "tunnel: tcp: connecting to %s:%u\n",
 	       svz_inet_ntoa (ip), ntohs (port));
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
       xsock->check_request = tnl_check_request_tcp_target;
       svz_sock_resize_buffers (xsock, UDP_BUF_SIZE, UDP_BUF_SIZE);
     }
@@ -281,10 +281,10 @@ tnl_create_socket (svz_socket_t *sock, int source)
 	  return NULL;
 	}
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "tunnel: udp: connecting to %s:%u\n",
 	       svz_inet_ntoa (ip), ntohs (port));
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
       xsock->handle_request = tnl_handle_request_udp_target;
       xsock->idle_func = tnl_idle;
       xsock->idle_counter = TNL_TIMEOUT;
@@ -301,10 +301,10 @@ tnl_create_socket (svz_socket_t *sock, int source)
 	  return NULL;
 	}
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "tunnel: icmp: connecting to %s\n",
 	       svz_inet_ntoa (ip));
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
       xsock->handle_request = tnl_handle_request_icmp_target;
       xsock->idle_func = tnl_idle;
       xsock->idle_counter = TNL_TIMEOUT;
@@ -321,10 +321,10 @@ tnl_create_socket (svz_socket_t *sock, int source)
 	  return NULL;
 	}
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "tunnel: pipe: connecting to %s\n",
 	       cfg->target->pipe_send.name);
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
       xsock->check_request = tnl_check_request_pipe_target;
       svz_sock_resize_buffers (xsock, UDP_BUF_SIZE, UDP_BUF_SIZE);
     }
@@ -454,13 +454,13 @@ tnl_check_request_tcp_target (svz_socket_t *sock)
   svz_socket_t *xsock = NULL;
   tnl_connect_t *source = sock->data;
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
   if (source == NULL || source->source_sock == NULL)
     {
       svz_log (LOG_FATAL, "tunnel: tcp target has no source connection\n");
       return -1;
     }
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
   /* obtain source connection */
   xsock = source->source_sock;
@@ -491,13 +491,13 @@ tnl_check_request_tcp_source (svz_socket_t *sock)
   tnl_connect_t *target = sock->data;
   svz_socket_t *xsock;
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
   if (target == NULL || target->target_sock == NULL)
     {
       svz_log (LOG_FATAL, "tunnel: tcp source has no target connection\n");
       return -1;
     }
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
   /* obtain target connection */
   xsock = target->target_sock;
@@ -522,13 +522,13 @@ tnl_handle_request_udp_target (svz_socket_t *sock, char *packet, int len)
   tnl_connect_t *source = sock->data;
   svz_socket_t *xsock = NULL;
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
   if (source == NULL || source->source_sock == NULL)
     {
       svz_log (LOG_FATAL, "tunnel: udp target has no source connection\n");
       return -1;
     }
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
   /* get source connection from data field */
   xsock = source->source_sock;
@@ -604,14 +604,14 @@ tnl_handle_request_icmp_target (svz_socket_t *sock, char *packet, int len)
   tnl_connect_t *source = sock->data;
   svz_socket_t *xsock = NULL;
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
   if (source == NULL || source->source_sock == NULL)
     {
       svz_log (LOG_FATAL,
 	       "tunnel: icmp target has no source connection\n");
       return -1;
     }
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
   /* get source connection from data field */
   xsock = source->source_sock;
@@ -704,13 +704,13 @@ tnl_disconnect_target (svz_socket_t *sock)
       return 0;
     }
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
   if (source == NULL || source->source_sock == NULL)
     {
       svz_log (LOG_FATAL, "tunnel: target has no source connection\n");
       return -1;
     }
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
   /* obtain source connection */
   xsock = source->source_sock;
@@ -718,20 +718,20 @@ tnl_disconnect_target (svz_socket_t *sock)
   /* if the source connection is ICMP send a disconnection message */
   if (sock->userflags & TNL_FLAG_SRC_ICMP)
     {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG,
 	       "tunnel: sending icmp disconnect on socket id %d\n",
 	       xsock->id);
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
       svz_icmp_send_control (xsock, ICMP_SERVEEZ_CLOSE);
     }
 
   /* if source is TCP or PIPE then shutdown referring connection */
   if (sock->userflags & (TNL_FLAG_SRC_TCP | TNL_FLAG_SRC_PIPE))
     {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "tunnel: shutdown referrer id %d\n", xsock->id);
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
       svz_sock_schedule_for_shutdown (xsock);
       xsock->data = NULL;
       tnl_free_connect (sock);
@@ -758,21 +758,21 @@ tnl_disconnect_source (svz_socket_t *sock)
   /* if target is TCP or PIPE shutdown referring connection */
   if (sock->userflags & (TNL_FLAG_TGT_TCP | TNL_FLAG_TGT_PIPE))
     {
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       if (target == NULL || target->target_sock == NULL)
 	{
 	  svz_log (LOG_DEBUG, "tunnel: tcp/pipe source has no "
 		   "target connection\n");
 	  return -1;
 	}
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
       /* get target connection */
       xsock = target->target_sock;
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
       svz_log (LOG_DEBUG, "tunnel: shutdown referrer id %d\n", xsock->id);
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
       svz_sock_schedule_for_shutdown (xsock);
       xsock->data = NULL;
       tnl_free_connect (sock);
