@@ -1,7 +1,7 @@
 /*
  * test/array-test.c - array tests
  *
- * Copyright (C) 2001 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2001, 2003 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: array-test.c,v 1.8 2001/11/23 13:18:39 ela Exp $
+ * $Id: array-test.c,v 1.9 2003/06/14 14:58:00 ela Exp $
  *
  */
 
@@ -313,11 +313,11 @@ main (int argc, char **argv)
   svz_array_destroy (array);
   test_ok ();
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
   /* is heap ok ? */
   test_print ("      heap: ");
   test (svz_allocated_bytes || svz_allocated_blocks);
-#endif /* ENABLE_DEBUG */
+#endif /* SVZ_ENABLE_DEBUG */
 
   return result;
 }
