@@ -1,7 +1,7 @@
 /*
  * test/hash-test.c - hash table tests
  *
- * Copyright (C) 2000, 2001, 2002 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2000, 2001, 2002, 2003 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: hash-test.c,v 1.14 2002/07/30 22:39:08 ela Exp $
+ * $Id: hash-test.c,v 1.15 2003/06/14 14:58:00 ela Exp $
  *
  */
 
@@ -200,7 +200,7 @@ main (int argc, char **argv)
   svz_hash_destroy (hash);
 
 
-#if ENABLE_DEBUG
+#if SVZ_ENABLE_DEBUG
   /* is heap ok ? */
   test_print ("               heap: ");
   test (svz_allocated_bytes || svz_allocated_blocks);
